/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the examples of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** BSD License Usage
** Alternatively, you may use this file under the terms of the BSD license
** as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of The Qt Company Ltd nor the names of its
**     contributors may be used to endorse or promote products derived
**     from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtWidgets>

#include "dialog.h"
bool expanded=true;
//! [0]
Dialog::Dialog(QWidget *parent):QWidget(parent)
{

    gridGroupBox = new QGroupBox();
    patientbutton = new QPushButton(this);

    createGridGroupBox();



    QVBoxLayout *mainLayout = new QVBoxLayout;
    setPatientButtonLayout();
    patientbutton->setFixedSize(1400-PATWIDTH_DIFF,110);
    patientbutton->setStyleSheet("QPushButton{background-color: #1f3d5a;}");


    mainLayout->addWidget(patientbutton);
    mainLayout->addWidget(tagCloudScrollArea);
    mainLayout->setSpacing(0);

    mainLayout->setMargin(0);

    //mainLayout->setAlignment(Qt::Horizontal);

    setLayout(mainLayout);

    setStyleSheet("QWidget {background-color: #1f3d5a;}");
    setAttribute( Qt::WA_AcceptTouchEvents,true);

    setFixedSize(1400-PATWIDTH_DIFF,900-PATHEIGHT_DIFF);
    setWindowTitle(tr("Basic Layouts"));
    connect(patientbutton, SIGNAL (released()), this, SLOT (handleButton()));
    for(int i=0;i<3;i++)
    {
        connect(lineEdits[i],SIGNAL(textChanged()),this,SLOT(onTextEditPatientButton()));
    }

    tagCloudScrollArea->hide();
    setFixedHeight(110);
    expanded=false;
    handleButton();
}

void Dialog::setPatientButtonLayout()
{
    QWidget *patientbuttonLayoutWidget=new QWidget(patientbutton);
    patientbuttonLayoutWidget->setFixedSize(1400-PATWIDTH_DIFF,110);
    QGridLayout *layoutPatientButton=new QGridLayout;
    patientbuttonLayoutWidget->setLayout(layoutPatientButton);

    PatientButtonGrid[0] = new QLabel(",");
    PatientButtonGrid[0]->setStyleSheet("QLabel {background-color:transparent; color : white;font-size:25px}");
    PatientButtonGrid[0]->setAlignment(Qt::AlignBottom);


    PatientButtonGrid[1] = new QLabel("Patient ID#");
    PatientButtonGrid[1]->setStyleSheet("QLabel {background-color:transparent; color : white;font-size:15px}");
    PatientButtonGrid[0]->setAlignment(Qt::AlignBottom);

    PatientButtonGrid[2] = new QLabel("BPM",patientbutton);
    PatientButtonGrid[2]->setStyleSheet("QLabel {background-color:transparent; color : white; font-size:15px}");


    PatientButtonGrid[3] = new QLabel("***",patientbutton);
    PatientButtonGrid[3]->setStyleSheet("QLabel {background-color:transparent; color : white; font-size:35px}");
    PatientButtonGrid[3]->setGeometry(1310,40,80,50);

    //PatientButtonGrid[3]->setGeometry(1200,100,100,100);
    layoutPatientButton->addWidget(PatientButtonGrid[0],0,0);
    layoutPatientButton->addWidget(PatientButtonGrid[1],1,0);
    layoutPatientButton->addWidget(PatientButtonGrid[2],0,1,Qt::AlignRight);
    //layoutPatientButton->addWidget(PatientButtonGrid[3],1,2,Qt::AlignRight);
    //layoutPatientButton->addWidget(PatientButtonGrid[4],1,2);

}



void Dialog::handleButton()
{
    if(expanded)
    {
        tagCloudScrollArea->hide();
        setFixedHeight(110);
        expanded=false;
    }
    else
    {
        tagCloudScrollArea->show();
        setFixedHeight(884-PATHEIGHT_DIFF);
        expanded=true;
    }


    QString identifier = "PATIENTDATAUPDATE";
    QString requestMsgID("-1");
    QVariantMap value;
    QVariantMap dataMap,dataMap1;

    dataMap.clear();
    dataMap1.clear();
    value.clear();

    value.insert("lastname",lineEdits[0]->toPlainText());
    value.insert("firstname",lineEdits[1]->toPlainText());
    value.insert("pid",lineEdits[2]->toPlainText());
    value.insert("visitnumber",lineEdits[3]->toPlainText());
   // m_PatListener->Update(identifier,value,requestMsgID);
}

void Dialog::onTextEditPatientButton()
{
    QString texttmp=lineEdits[0]->toPlainText()+","+lineEdits[1]->toPlainText();
    PatientButtonGrid[0]->setText(texttmp);
    QString tempPatientIdLength=lineEdits[2]->toPlainText();

    PatientButtonGrid[1]->setText(QString("Patient Id#")+tempPatientIdLength);

}





QTime  paintTime;

class testQLabel:public QLabel
{
public:
	testQLabel(const QString &text):QLabel(text){}


};

void Dialog::updatePatientBannerDetails()
{
    QSize editSize(600,60);
    qreal fontSize = 20;
    labels[0] = new QLabel("Last Name");
    labels[0]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[0] = new QTextEdit;
    lineEdits[0]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[0]->setFixedSize(editSize);
    lineEdits[0]->setFontPointSize(fontSize);


    labels[1] = new QLabel("First Name");
    labels[1]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[1] = new QTextEdit;
    lineEdits[1]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[1]->setFixedSize(editSize);
    lineEdits[1]->setFontPointSize(fontSize);

    labels[2] = new QLabel("Patient ID");
    labels[2]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[2] = new QTextEdit;
    lineEdits[2]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[2]->setFixedSize(editSize);
    lineEdits[2]->setFontPointSize(fontSize);

    labels[3] = new QLabel("Visit Number");
    labels[3]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[3] = new QTextEdit;
    lineEdits[3]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[3]->setFixedSize(editSize);
    lineEdits[3]->setFontPointSize(fontSize);

    labels[4] = new QLabel("Height:");
    labels[4]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[4] = new QTextEdit;
    lineEdits[4]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[4]->setFixedSize(editSize);
    lineEdits[4]->setFontPointSize(fontSize);

    labels[5] = new QLabel("Weight:");
    labels[5]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[5] = new QTextEdit;
    lineEdits[5]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[5]->setFixedSize(editSize);
    lineEdits[5]->setFontPointSize(fontSize);

    labels[6] = new QLabel("Medications:");
    labels[6]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[6] = new QTextEdit;
    lineEdits[6]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[6]->setFixedSize(editSize);
    lineEdits[6]->setFontPointSize(fontSize);

    labels[7] = new QLabel("Test Indicvation:");
    labels[7]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[7] = new QTextEdit;
    lineEdits[7]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[7]->setFixedSize(editSize);
    lineEdits[7]->setFontPointSize(fontSize);

    labels[8] = new QLabel("Technician:");
    labels[8]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[8] = new QTextEdit;
    lineEdits[8]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[8]->setFixedSize(editSize);
    lineEdits[8]->setFontPointSize(fontSize);

    labels[9] = new QLabel("Last Name:");
    labels[9]->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    lineEdits[9] = new QTextEdit;
    lineEdits[9]->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    lineEdits[9]->setFixedSize(editSize);
    lineEdits[9]->setFontPointSize(fontSize);




    for (int i = 0; i < NumGridRows; ++i)
    {
        layoutWidget->layout()->addWidget(labels[i]);
        layoutWidget->layout()->addWidget(lineEdits[i]);
    }

    for (int i = 0; i < 30; ++i)
    {

    	QLabel  *labeltest = new QLabel(QString("Last Name: %1").arg(i));
    	labeltest->setStyleSheet("QLabel { background-color : #1f3d5a; color : white; font-size:18px }");
    	QTextEdit *lineEditstest = new QTextEdit;
    	lineEditstest->setStyleSheet("QTextEdit { background-color : black; color : white;}");
    	lineEditstest->setFixedSize(editSize);
    	lineEditstest->setFontPointSize(fontSize);

    	layoutWidget->layout()->addWidget(labeltest);
    	layoutWidget->layout()->addWidget(lineEditstest);
    }
}



bool Dialog::event(QEvent *ev)
{
    //qDebug()<<"\n.........event type parent......"<<ev->type();

    bool ret=QWidget::event(ev);

    return ret;
}




class windowWidget:public QWidget
{
public:
    windowWidget(QWidget *parent):QWidget(parent){paintTime.start();}
//    void paintEvent(QPaintEvent *event);
public slots:
//    bool event(QEvent *event);

};


class widgetScrollArea:public QScrollArea
{

public:


public slots:
   // bool viewportEvent(QEvent *event);

};



bool touchBegin=0,ScrollPatientBanner=0;

//    return true;
//}



void Dialog::createGridGroupBox()
{
//    patientSaveLayoutWidget=new QWidget(this);

    layoutWidget = new windowWidget(this);
//    layoutWidget->setMaximumWidth(500);
    QFormLayout *patientWidgetLayout = new QFormLayout(layoutWidget);
    patientWidgetLayout->setSpacing(30);
    updatePatientBannerDetails();

    layoutWidget->setLayout(patientWidgetLayout);

//    layoutWidget->layout()->setSizeConstraint(QLayout::SetMinAndMaxSize);
    layoutWidget->setStyleSheet("QWidget {background-color: #1f3d5a;}");

    tagCloudScrollArea = new widgetScrollArea();
    tagCloudScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    tagCloudScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
//    tagCloudScrollArea->setWidgetResizable(true);
    tagCloudScrollArea->setWidget(layoutWidget);
    layoutWidget->setAttribute(Qt::WA_NoSystemBackground);

    tagCloudScrollArea->verticalScrollBar()->setSingleStep(30);

    QScroller::grabGesture(tagCloudScrollArea, QScroller::LeftMouseButtonGesture);

    QPushButton *layoutSaveWidget = new QPushButton(tagCloudScrollArea);
    layoutSaveWidget->setFixedSize(180,50);
    layoutSaveWidget->move(1200-PATWIDTH_DIFF,650-PATHEIGHT_DIFF);
    layoutSaveWidget->setStyleSheet("QPushButton{ border: none;border-radius: 4px;color: #ffffff;\
                                     background-color: #0b98d5;\
                                     font-size: 20px;\
                                     outline: none;}");
    layoutSaveWidget->setText("Save");
    connect(layoutSaveWidget, SIGNAL (released()), this, SLOT (handleButton()));

}


void Dialog::setHeartRate(int hr)
{
    PatientButtonGrid[3]->setText(QString("%1").arg(hr));
}
